@@ -14,33 +14,16 @@ from strct.dicts import (
 )
 
 from .exceptions import UnsupporedFormatException
+from .paths import (
+    _xdg_cfg_dpath,
+    _xdg_cache_dpath,
+    _legacy_cfg_dpath,
+)
+
 
 SEP = '__'
 
 
-def _legacy_cfg_dpath(namespace):
-    return os.path.join(
-        os.path.expanduser('~'),
-        '.{}'.format(namespace),
-    )
-
-
-XDG_CONFIG_HOME_VARNAME = 'XDG_CONFIG_HOME'
-
-
-def _xdg_cfg_dpath(namespace):
-    if XDG_CONFIG_HOME_VARNAME in os.environ:  # pragma: no cover
-        return os.path.join(
-            os.environ[XDG_CONFIG_HOME_VARNAME],
-            namespace,
-        )
-    return os.path.join(
-        os.path.expanduser('~'),
-        '.config',
-        namespace,
-    )
-
-
 class Birch(collections.abc.Mapping):
     """Defines a configuration access object.
 
@@ -141,6 +124,16 @@ class Birch(collections.abc.Mapping):
         """
         return self._xdg_cfg_dpath
 
+    def xdg_cache_dpath(self):
+        """Returns the XDG-compliant cache home for this namespace.
+
+        If the ``XDG_CONFIG_HOME`` environmet variable is set to some path
+        `<xdg_cfg_home>`, this will return the path
+        `<xdg_cfg_home>/<namespace>/`. Otherwise, this will return the path
+        `<home_dir>/.config/<namespace>/`.
+        """
+        return _xdg_cache_dpath(namespace=self.namespace)
+
     def reload(self):
         """Reloads configuration values from all sources."""
         self._val_dict = self._build_val_dict()
@@ -356,8 +349,8 @@ class Birch(collections.abc.Mapping):
     def _leafcounter(node):
         if isinstance(node, dict):
             return sum([Birch._leafcounter(node[n]) for n in node])
-        else:
-            return 1
+        # else:
+        return 1
 
     # implementing a collections.abc.mapping abstract method
     def __len__(self):
@@ -367,3 +360,26 @@ class Birch(collections.abc.Mapping):
     def __iter__(self):
         for keytupl, value in key_tuple_value_nested_generator(self._val_dict):
             yield SEP.join(keytupl), value
+
+    def cfg_key_to_env_var(self, key):
+        """Returns the environment variable corresponding to a given key.
+
+        Parmeters
+        ---------
+        key : str
+            The configuration key to get the environment variable for.
+
+        Returns
+        -------
+        env_var : str
+            The name of environment variable corresponding to the given
+            configuration key.
+
+        Example
+        -------
+        >>> import os;
+        >>> zubat_cfg = Birch('zubat')
+        >>> zubat_cfg.cfg_key_to_env_var('host')
+        'ZUBAT__HOST'
+        """
+        return '{}__{}'.format(self._upper_namespace, key.upper())
