@@ -139,7 +139,7 @@ def test_json():
     assert cfg['SERVER']['port'] == 1293
     assert cfg['server']['port'] == 1293
     with pytest.raises(KeyError):
-        cfg['SERVER'][4]
+        res = cfg['SERVER'][4]
     assert cfg['{}_SERVER__PORT'.format(NSPACE)] == 1293
     assert cfg['{}__SERVER__PORT'.format(NSPACE)] == 1293
     assert cfg['nega'] == 'Uvavo'
@@ -148,7 +148,7 @@ def test_json():
     assert cfg['MAN']['HEIGHT'] == '175'
     assert cfg['MAN__WEIGHT'] == '73'
     with pytest.raises(ValueError):
-        cfg[54]
+        res = cfg[54]
 
     assert cfg['MOCK__LVL'] == 'A'
     assert cfg['mock__lvl'] == 'A'
@@ -410,3 +410,15 @@ def test_xdg_cfg_dpath():
         homedir = os.path.expanduser('~')
         expected_path = os.path.join(homedir, '.config', NSPACE4)
     assert expected_path in returned_dpath
+
+
+def test_xdg_cache_dpath():
+    cfg = Birch(NSPACE4)
+    returned_dpath = cfg.xdg_cache_dpath()
+    try:
+        xdg_cache_home = os.environ['XDG_CACHE_HOME']
+        expected_path = os.path.join(xdg_cache_home, NSPACE4)
+    except KeyError:
+        homedir = os.path.expanduser('~')
+        expected_path = os.path.join(homedir, '.cache', NSPACE4)
+    assert expected_path in returned_dpath
